// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:analyzer/dart/element/element.dart';
import 'package:build/build.dart';
import 'package:source_gen/source_gen.dart';
import 'package:wyatt_deferred_widget_annotation/wyatt_deferred_widget_annotation.dart';

class DeferredWidgetGenerator extends GeneratorForAnnotation<Deferred> {
  @override
  FutureOr<String> generateForAnnotatedElement(
    Element element,
    ConstantReader annotation,
    BuildStep buildStep,
  ) {
    /// Check element type
    if (element is! ClassElement) {
      throw InvalidGenerationSourceError(
        'Only classes can be annotated with "Deferred". "$element" is '
        'not a ClassElement.',
        element: element,
      );
    }

    print(element.location);

//     final generatedCode = StringBuffer()
//       ..write('''
// import 'package:flutter/material.dart';
// import 'package:wyatt_deferred_widget_annotation/wyatt_deferred_widget_annotation.dart';
// import 'package:wyatt_deferred_widget_annotation_example/widgets/my_awesome_widget2.dart'
//     deferred as my_awesome_widget2;

// ''');
    return '';
  }
}
